==> beast-0.5.0-rc1.tar.gz: beast-0.5.0-rc1/beast-gtk/gxk/gxkmarshal.h <==

#ifndef __gxk_marshal_MARSHAL_H__
#define __gxk_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:POINTER (gxkmarshal.list:25) */
#define gxk_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gxk_marshal_NONE__POINTER	gxk_marshal_VOID__POINTER

/* NONE:POINTER,POINTER (gxkmarshal.list:26) */
extern void gxk_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__POINTER_POINTER	gxk_marshal_VOID__POINTER_POINTER

/* NONE:UINT,UINT (gxkmarshal.list:27) */
extern void gxk_marshal_VOID__UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT	gxk_marshal_VOID__UINT_UINT

/* NONE:UINT,INT (gxkmarshal.list:28) */
extern void gxk_marshal_VOID__UINT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_INT	gxk_marshal_VOID__UINT_INT

/* NONE:UINT,UINT,UINT,UINT,UINT,UINT,UINT (gxkmarshal.list:29) */
extern void gxk_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_UINT_UINT_UINT_UINT_UINT	gxk_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT

/* NONE:INT (gxkmarshal.list:30) */
#define gxk_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
#define gxk_marshal_NONE__INT	gxk_marshal_VOID__INT

/* NONE:UINT (gxkmarshal.list:31) */
#define gxk_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define gxk_marshal_NONE__UINT	gxk_marshal_VOID__UINT

/* NONE:UINT,UINT,FLOAT (gxkmarshal.list:32) */
extern void gxk_marshal_VOID__UINT_UINT_FLOAT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_FLOAT	gxk_marshal_VOID__UINT_UINT_FLOAT

/* NONE:UINT,UINT,INT,BOXED (gxkmarshal.list:33) */
extern void gxk_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_INT_BOXED	gxk_marshal_VOID__UINT_UINT_INT_BOXED

/* NONE:UINT,UINT,BOXED (gxkmarshal.list:34) */
extern void gxk_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_BOXED	gxk_marshal_VOID__UINT_UINT_BOXED

/* BOOL:BOOL (gxkmarshal.list:35) */
extern void gxk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
#define gxk_marshal_BOOL__BOOL	gxk_marshal_BOOLEAN__BOOLEAN

/* NONE:UINT,POINTER (gxkmarshal.list:36) */
#define gxk_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
#define gxk_marshal_NONE__UINT_POINTER	gxk_marshal_VOID__UINT_POINTER

/* NONE:OBJECT,OBJECT (gxkmarshal.list:37) */
extern void gxk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define gxk_marshal_NONE__OBJECT_OBJECT	gxk_marshal_VOID__OBJECT_OBJECT

/* NONE:STRING (gxkmarshal.list:38) */
#define gxk_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
#define gxk_marshal_NONE__STRING	gxk_marshal_VOID__STRING

/* NONE:BOOLEAN (gxkmarshal.list:39) */
#define gxk_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define gxk_marshal_NONE__BOOLEAN	gxk_marshal_VOID__BOOLEAN

/* BOOLEAN:UINT (gxkmarshal.list:40) */
extern void gxk_marshal_BOOLEAN__UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* NONE:BOXED (gxkmarshal.list:41) */
#define gxk_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
#define gxk_marshal_NONE__BOXED	gxk_marshal_VOID__BOXED

G_END_DECLS

#endif /* __gxk_marshal_MARSHAL_H__ */

==> beast-0.5.5-rc3.tar.gz: beast-0.5.5-rc3/beast-gtk/gxk/gxkmarshal.h <==

#ifndef __gxk_marshal_MARSHAL_H__
#define __gxk_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:POINTER (gxkmarshal.list:25) */
#define gxk_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gxk_marshal_NONE__POINTER	gxk_marshal_VOID__POINTER

/* NONE:POINTER,POINTER (gxkmarshal.list:26) */
extern void gxk_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__POINTER_POINTER	gxk_marshal_VOID__POINTER_POINTER

/* NONE:UINT,UINT (gxkmarshal.list:27) */
extern void gxk_marshal_VOID__UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT	gxk_marshal_VOID__UINT_UINT

/* NONE:UINT,INT (gxkmarshal.list:28) */
extern void gxk_marshal_VOID__UINT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_INT	gxk_marshal_VOID__UINT_INT

/* NONE:UINT,UINT,UINT,UINT,UINT,UINT,UINT (gxkmarshal.list:29) */
extern void gxk_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_UINT_UINT_UINT_UINT_UINT	gxk_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT

/* NONE:INT (gxkmarshal.list:30) */
#define gxk_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
#define gxk_marshal_NONE__INT	gxk_marshal_VOID__INT

/* NONE:UINT (gxkmarshal.list:31) */
#define gxk_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define gxk_marshal_NONE__UINT	gxk_marshal_VOID__UINT

/* NONE:UINT,UINT,FLOAT (gxkmarshal.list:32) */
extern void gxk_marshal_VOID__UINT_UINT_FLOAT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_FLOAT	gxk_marshal_VOID__UINT_UINT_FLOAT

/* NONE:UINT,UINT,INT,BOXED (gxkmarshal.list:33) */
extern void gxk_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_INT_BOXED	gxk_marshal_VOID__UINT_UINT_INT_BOXED

/* NONE:UINT,UINT,BOXED (gxkmarshal.list:34) */
extern void gxk_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define gxk_marshal_NONE__UINT_UINT_BOXED	gxk_marshal_VOID__UINT_UINT_BOXED

/* BOOL:BOOL (gxkmarshal.list:35) */
extern void gxk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
#define gxk_marshal_BOOL__BOOL	gxk_marshal_BOOLEAN__BOOLEAN

/* NONE:UINT,POINTER (gxkmarshal.list:36) */
#define gxk_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
#define gxk_marshal_NONE__UINT_POINTER	gxk_marshal_VOID__UINT_POINTER

/* NONE:OBJECT,OBJECT (gxkmarshal.list:37) */
extern void gxk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define gxk_marshal_NONE__OBJECT_OBJECT	gxk_marshal_VOID__OBJECT_OBJECT

/* NONE:STRING (gxkmarshal.list:38) */
#define gxk_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
#define gxk_marshal_NONE__STRING	gxk_marshal_VOID__STRING

/* NONE:STRING,STRING (gxkmarshal.list:39) */
extern void gxk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define gxk_marshal_NONE__STRING_STRING	gxk_marshal_VOID__STRING_STRING

/* NONE:BOOLEAN (gxkmarshal.list:40) */
#define gxk_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define gxk_marshal_NONE__BOOLEAN	gxk_marshal_VOID__BOOLEAN

/* BOOLEAN:UINT (gxkmarshal.list:41) */
extern void gxk_marshal_BOOLEAN__UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* NONE:BOXED (gxkmarshal.list:42) */
#define gxk_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
#define gxk_marshal_NONE__BOXED	gxk_marshal_VOID__BOXED

G_END_DECLS

#endif /* __gxk_marshal_MARSHAL_H__ */
